/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
/*
    devices.h

	Header files for Watchdog / DIO / BIOSInfo / Uart Mode functions

    2009-11-25	Freddy Liao
		new release
*/


#ifndef _V2101CE_DEVICES_H
#define _V2101CE_DEVICES_H

#include <windows.h>
#include "fsioctl.h"

/*******************************  IMPORTANT NOTICE *********************************/
/*  You have to copy mxdev.dll to \windows directory                               */
/*  The mxdev.dll is in the path "C:\Windows CE Tools\wce600\V2101-CE\Lib\x86"  */

/*********      IO Control Code, Definition, Structure       *******/
/* extra DeviceIOControl Code for Digial Input and Digital Output */
#define IOCTL_SET_DOUT          CTL_CODE( 0, 51, 0, 0)
#define IOCTL_GET_DOUT          CTL_CODE( 0, 52, 0, 0)
#define IOCTL_GET_DIN			CTL_CODE( 0, 53, 0, 0)
#define IOCTL_GET_DIN_ALL		CTL_CODE( 0, 54, 0, 0)
#define IOCTL_GET_DOUT_ALL		CTL_CODE( 0, 55, 0, 0)

/* extra DeviceIOControl Code for Moxa MU860 UART */
#define MOXA					0x400
#define MOXA_SET_OP_MODE		(MOXA + 66)
#define MOXA_GET_OP_MODE		(MOXA + 67)

#define RS232_MODE				0	
#define RS485_2WIRE_MODE		1
#define RS422_MODE				2
#define RS485_4WIRE_MODE		3
#define OP_MODE_MASK			3

/* IO Control Code for Watchdog */
#define IOCTL_START_WDG				CTL_CODE( 0, 164, 0, 0)
#define IOCTL_STOP_WDG				CTL_CODE( 0, 165, 0, 0)
#define IOCTL_REFRESH_WDG			CTL_CODE( 0, 166, 0, 0)

/*  BIOS Error Bits */
#define BIOS_BATTERY_FAILURE			0x80
#define BIOS_CMOS_CHECKSUM				0x40
#define BIOS_EQUIPMENT_MISSING			0x20
#define BIOS_MEMORY_SIZE_CHANGED		0x10
#define BIOS_FIXED_DISK_CONTROLLER		0x8
#define BIOS_DISPLAY_SWITCH_DISMATCH	0x4
#define BIOS_KEYBOARD_ERROR				0x2

/* extra DeviceIOControl Code for BIOS Info */
#define MOXA_READ_LVDS_SETTINGS	(MOXA + 68)
#define MOXA_READ_BIOS_STATUS	(MOXA + 69)

/* IO Control Code for Reboot */
#define IOCTL_HAL_REBOOT		CTL_CODE(FILE_DEVICE_HAL, 15, METHOD_BUFFERED, FILE_ANY_ACCESS)

/****************************  API     ******************************/

/*	open the watchdog 
	Inputs:
		DWORD : refresh period
	Outpus:
		None
	Returns:
		the watchdog handle for later use
*/
HANDLE watchdog_init(DWORD dwRefreshPeriod);

/*	act the watchdog
	Inputs:
		<hWdg>	the watchdog handle
	Outpus:
		None
	Returns:
		TRUE on success, FALSE indicates the function fails
*/
BOOL watchdog_refresh(HANDLE hWdg);

/*	close the watchdog
	Inputs:
		<hWdg>	the watchdog handle
	Outpus:
		None
	Returns:
		TRUE on success, FALSE indicates the function fails
*/
BOOL watchdog_release(HANDLE hWdg);


/*	retrive the BIOS error code
	Inputs:
		None
	Outpus:
		None
	Returns:
		0 indictes no error. otherwise, a 8-bit number indicating a combination of errors
*/
BYTE Get_BIOS_Status();


/*	open the DIO 
	Inputs:
		None
	Outpus:
		None
	Returns:
		the DIO handle for later use
*/
HANDLE mxdio_init(void);

/*	close the DIO
	Inputs:
		<fd>	the DIO handle
	Outpus:
		None
	Returns:
		None
*/
void mxdio_stop(HANDLE fd);

/*	set the value (HIGH or LOW) of DO
	Inputs:
		<fd>	  the DIO handle
		<port_no> the port number (started from 0)
		<data>    1:HIGH, 0:LOW
	Returns:
		0 on success, otherwise the function fails
*/
int mxdio_set_dout(HANDLE fd, unsigned int port_no, unsigned int data);

/*	get the value (HIGH or LOW) of DO
	Inputs:
		<fd>	  the DIO handle
		<port_no> the port number (started from 0)
	Returns:
		1 indicates HIGH, 0 indicates LOW, otherwise the function fails
*/
int mxdio_get_dout(HANDLE fd, unsigned int port_no);

/*	get the value (HIGH or LOW) of DI
	Inputs:
		<fd>	  the DIO handle
		<port_no> the port number (started from 0)
	Returns:
		1 indicates HIGH, 0 indicates LOW, otherwise the function fails
*/
int mxdio_get_din(HANDLE fd, unsigned int port);


/*	set the serial port interface
	Inputs:
		<port>	the serial port number
		<mode>  0: RS232, 1:RS485-2W, 2:RS422, 3:RS-485-4W
	Returns:
		TRUE on success, FALSE indicates the function fails
*/
BOOL uart_setmode(int port, int mode);

/*	get the serial port interface
	Inputs:
		<port>	  the serial port number
	Returns:
		0: RS232, 1:RS485-2W, 2:RS422, 3:RS-485-4W
*/
DWORD uart_getmode(int port);


#endif
